# ifndef yyControlFlow
# define yyControlFlow

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* ControlFlow_Exit) ARGS ((void));

extern void ControlFlow ARGS ((tTree t));

extern void BeginControlFlow ARGS ((void));
extern void CloseControlFlow ARGS ((void));

# endif
